@@ -1,6 +1,6 @@
 package SPVM::Sys;
 
-our $VERSION = "0.507";
+our $VERSION = "0.508";
 
 1;
 
@@ -432,6 +432,18 @@ C<static method gmtime : L<Sys::Time::Tm|SPVM::Sys::Time::Tm> ($time : long);>
 
 Works just like L</"localtime">, but the returned values are localized for the standard Greenwich time zone.
 
+=head2 utime
+
+C<static method utime : void ($atime : long, $mtime : long, $filename : string);>
+
+Changes the access time and the modification time of the inode specified by the file $filename given the access time $atime and the modification time $mtime.
+
+If $atime < 0 and $mtime < 0, changes the access time and the modification time to the current time..
+
+Exceptions:
+
+Exceptions thrown by the L<utime|SPVM::Sys::Time/"utime"> method in the Sys::Time class could be thrown.
+
 =head2 stat
 
 C<static method stat : L<Sys::IO::Stat|SPVM::Sys::IO::Stat> ($path : string);>
@@ -534,9 +546,17 @@ Causes the program to sleep for $seconds seconds.
 
 C<static method ioctl : int ($fd : int, $request : int, $request_arg_ref : object of byte[]|short[]|int[]|long[]|float[]|double[]|object = undef);>
 
-Calls the L<ioctlsocket|SPVM::Sys::Ioctl/"ioctlsocket"> method in the L<Sys::Ioctl|SPVM::Sys::Ioctl> class in Windows.
+Windows:
 
-Calls the L<ioctl|SPVM::Sys::Ioctl/"ioctl"> method in the L<Sys::Ioctl|SPVM::Sys::Ioctl> class in other systems.
+Calls the L<ioctlsocket|SPVM::Sys::Ioctl/"ioctlsocket"> method in the L<Sys::Ioctl|SPVM::Sys::Ioctl> class and returns its return value.
+
+OSs other than Windows:
+
+Calls the L<ioctl|SPVM::Sys::Ioctl/"ioctl"> method in the L<Sys::Ioctl|SPVM::Sys::Ioctl> class and returns its return value.
+
+Excetpions:
+
+Excetpions thrown by the L<ioctl|SPVM::Sys::Ioctl/"ioctl"> method or the L<ioctlsocket|SPVM::Sys::Ioctl/"ioctlsocket"> method in the L<Sys::Ioctl|SPVM::Sys::Ioctl> class could be thrown.
 
 =head2 select
 
@@ -779,14 +799,6 @@ Creates a L<Sys::IO::Stat|SPVM::Sys::IO::Stat> object and calls the L<lstat|SPVM
 
 And returns the a L<Sys::IO::Stat|SPVM::Sys::IO::Stat> object.
 
-=head2 utime
-
-C<static method utime : void ($atime : long, $mtime : long, $filename : string);>
-
-Unless $atime < 0 and $mtime < 0, creates a L<Sys::IO::Utimbuf|SPVM::Sys::IO::Utimbuf> object.
-
-And calls the L<utime|SPVM::Sys::IO/"utime"> method in the L<Sys::IO|SPVM::Sys::IO> class.
-
 =head2 chown
 
 C<static method chown : void ($owner : int, $group : int, $path : string);>
@@ -799,6 +811,24 @@ C<static method fcntl : int ($fd : int, $command : int, $command_arg : object of
 
 Calls the L<fcntl|SPVM::Sys::IO/"fcntl"> method in the L<Sys::IO|SPVM::Sys::IO> class.
 
+=head2 STDIN
+
+C<static method STDIN : L<Sys::IO::FileStream|SPVM::Sys::IO::FileStream> ();>
+
+Returns the stdin opened by the SPVM language.
+
+=head2 STDOUT
+
+C<static method STDOUT : L<Sys::IO::FileStream|SPVM::Sys::IO::FileStream> ();>
+
+Returns the stdout opened by the SPVM language.
+
+=head2 STDERR
+
+C<static method STDERR : L<Sys::IO::FileStream|SPVM::Sys::IO::FileStream> ();>
+
+Returns the stderr opened by the SPVM language.
+
 =head2 open
 
 C<static method open : void ($stream_ref : L<Sys::IO::FileStream|SPVM::Sys::IO::FileStream>[], $open_mode : string, $file_name : string);>
@@ -881,24 +911,6 @@ C<static method say : void ($stream : L<Sys::IO::FileStream|SPVM::Sys::IO::FileS
 
 Calls the L</"print"> method adding C<\n> to the end of $string.
 
-=head2 STDIN
-
-C<static method STDIN : L<Sys::IO::FileStream|SPVM::Sys::IO::FileStream> ();>
-
-Calls the L<stdin|SPVM::Sys::IO/"spvm_stdin"> method in the L<Sys::IO|SPVM::Sys::IO> class.
-
-=head2 STDOUT
-
-C<static method STDOUT : L<Sys::IO::FileStream|SPVM::Sys::IO::FileStream> ();>
-
-Calls the L<stdout|SPVM::Sys::IO/"spvm_stdout"> method in the L<Sys::IO|SPVM::Sys::IO> class.
-
-=head2 STDERR
-
-C<static method STDERR : L<Sys::IO::FileStream|SPVM::Sys::IO::FileStream> ();>
-
-Calls the L<stderr|SPVM::Sys::IO/"spvm_stderr"> method in the L<Sys::IO|SPVM::Sys::IO> class.
-
 =head2 signal
 
 C<static method signal : void ($signum : int, $handler_name : string);>
@@ -1239,8 +1251,6 @@ Searches a group entry given The group name $name. If found, returns the group e
 
 =item * L<Sys::IO::Stat|SPVM::Sys::IO::Stat>
 
-=item * L<Sys::IO::Utimbuf|SPVM::Sys::IO::Utimbuf>
-
 =item * L<Sys::IO::Windows|SPVM::Sys::IO::Windows>
 
 =item * L<Sys::OS|SPVM::Sys::OS>
@@ -1323,6 +1333,8 @@ Searches a group entry given The group name $name. If found, returns the group e
 
 =item * L<Sys::Time::Util|SPVM::Sys::Time::Util>
 
+=item * L<Sys::Time::Utimbuf|SPVM::Sys::Time::Utimbuf>
+
 =item * L<Sys::User|SPVM::Sys::User>
 
 =item * L<Sys::User::Group|SPVM::Sys::User::Group>
