@@ -16,189 +16,313 @@ C<Sys::IO> is the class for the file IO.
 
 =head1 Class Methods
 
-=head2 open
+=head2 stdin
 
-C<static method open : int ($path : string, $flags : int, $mode : int = 0);>
+C<static method stdin : L<Sys::IO::FileStream|SPVM::Sys::IO::FileStream> ();>
 
-Given a pathname for a file, open() returns a file descriptor, a small, nonnegative integer for use in subsequent system calls (read(2), write(2), lseek(2), fcntl(2), etc.). The file descriptor returned by a successful call will be the lowest-numbered file descriptor not currently open for the process.
+Returns L<stdin|https://linux.die.net/man/3/stdin>.
 
-See the L<open|https://linux.die.net/man/2/open> function in Linux.
+=head2 stdout
 
-See L<Sys::IO::Constant|SPVM::Sys::IO::Constant> about the constant value for the flags and the mode.
+C<static method stdout : L<Sys::IO::FileStream|SPVM::Sys::IO::FileStream> ();>
 
-=head2 read
+Returns L<stdout|https://linux.die.net/man/3/stdout>.
 
-C<static method read : int ($fd : int, $buf : mutable string, $count : int, $buf_offset : int = 0);>
+=head2 stderr
 
-read() attempts to read up to count bytes from file descriptor fd into the buf starting at buf + buf_offset.
+C<static method stderr : L<Sys::IO::FileStream|SPVM::Sys::IO::FileStream> ();>
 
-See the L<read|https://linux.die.net/man/2/read> function in Linux.
+Returns L<stderr|https://linux.die.net/man/3/stderr>.
 
-=head2 write
+=head2 spvm_stdin
 
-C<static method write : int ($fd : int, $buf : string, $count : int, $buf_offset : int = 0);>
+C<static method spvm_stdin : L<Sys::IO::FileStream|SPVM::Sys::IO::FileStream> ();>
 
-write() writes up to count bytes from the buf pointed buf + buf_offset to the file referred to by the file descriptor fd.
+Returns the L<stdin|SPVM::Document::NativeAPI/"spvm_stdin"> opened by the SPVM language.
 
-See the L<write|https://linux.die.net/man/2/write> function in Linux.
+=head2 spvm_stdout
 
-=head2 lseek
+C<static method spvm_stdout : L<Sys::IO::FileStream|SPVM::Sys::IO::FileStream> ();>
 
-C<static method lseek : long ($fd : int, $offset : long, $whence : int);>
+Returns the L<stdout|SPVM::Document::NativeAPI/"spvm_stdout"> opened by the SPVM language.
 
-The lseek() function repositions the offset of the open file associated with the file descriptor fd to the argument offset according to the directive whence as follows:
+=head2 spvm_stderr
 
-See the L<lseek|https://linux.die.net/man/2/lseek> function in Linux.
+C<static method spvm_stderr : L<Sys::IO::FileStream|SPVM::Sys::IO::FileStream> ();>
 
-See L<Sys::IO::Constant|SPVM::Sys::IO::Constant> about the constant value for the whence.
-
-=head2 close
-
-C<static method close : int ($fd : int);>
-
-close() closes a file descriptor, so that it no longer refers to any file and may be reused. Any record locks (see fcntl(2)) held on the file it was associated with, and owned by the process, are removed (regardless of the file descriptor that was used to obtain the lock).
-
-See the L<close|https://linux.die.net/man/2/close> function in Linux.
+Returns the L<stderr|SPVM::Document::NativeAPI/"spvm_stderr"> opened by the SPVM language.
 
 =head2 fopen
 
 C<static method fopen : L<Sys::IO::FileStream|SPVM::Sys::IO::FileStream> ($path : string, $mode : string);>
 
-The fopen() function opens the file whose name is the string pointed to by path and associates a stream with it.
+Calls the L<fopen|https://linux.die.net/man/3/fopen> function and returns its return value.
 
-See the L<fopen|https://linux.die.net/man/3/fopen> function in Linux.
+Exceptions:
 
-The return value is a L<Sys::IO::FileStream|SPVM::Sys::IO::FileStream> object.
+$path must be defined. Otherwise an exception is thrown.
+
+$mode must be defined. Otherwise an exception is thrown.
+
+If the fopen function failed, an exception is thrown with C<eval_error_id> set to the basic type ID of the L<Error::System|SPVM::Error::System> class.
 
 =head2 fdopen
 
 C<static method fdopen : L<Sys::IO::FileStream|SPVM::Sys::IO::FileStream> ($fd : int, $mode : string);>
 
-The fdopen() function associates a stream with the existing file descriptor, fd. The mode of the stream (one of the values "r", "r+", "w", "w+", "a", "a+") must be compatible with the mode of the file descriptor. The file position indicator of the new stream is set to that belonging to fd, and the error and end-of-file indicators are cleared. Modes "w" or "w+" do not cause truncation of the file. The file descriptor is not dup'ed, and will be closed when the stream created by fdopen() is closed. The result of applying fdopen() to a shared memory object is undefined.
-
-See the L<fdopen|https://linux.die.net/man/3/fdopen> function in Linux.
-
-The return value is a L<Sys::IO::FileStream|SPVM::Sys::IO::FileStream> object.
+Calls the L<fdopen|https://linux.die.net/man/3/fdopen> function and returns its return value.
 
 Exceptions:
 
 $fd must be greater than or equal to 0. Otherwise an exception is thrown.
 
+$mode must be defined. Otherwise an exception is thrown.
+
+If the fdopen function failed, an exception is thrown with C<eval_error_id> set to the basic type ID of the L<Error::System|SPVM::Error::System> class.
+
 =head2 fileno
 
 C<static method fileno : int ($stream : L<Sys::IO::FileStream|SPVM::Sys::IO::FileStream>);>
 
-The function fileno() examines the argument stream and returns its integer descriptor.
+Calls the L<fileno|https://linux.die.net/man/3/fileno> function and returns its return value.
 
-See the L<fileno|https://linux.die.net/man/3/fileno> function in Linux.
+Exceptions:
 
-The file stream is a L<Sys::IO::FileStream|SPVM::Sys::IO::FileStream> object.
+$stream must be defined. Otherwise an exception is thrown.
+
+If the fileno function failed, an exception is thrown with C<eval_error_id> set to the basic type ID of the L<Error::System|SPVM::Error::System> class.
 
 =head2 fread
 
 C<static method fread : int ($ptr : mutable string, $size : int, $nmemb : int, $stream : L<Sys::IO::FileStream|SPVM::Sys::IO::FileStream>, $ptr_offset : int = 0);>
 
-The function fread() reads nmemb elements of data, each size bytes long, from the stream pointed to by stream, storing them at the location given by ptr + ptr_offset.
+Calls the L<fread|https://linux.die.net/man/3/fread> function and returns its return value.
 
-See the L<fread|https://linux.die.net/man/3/fread> function in Linux.
+Exceptions:
+
+$ptr must be defined. Otherwise an exception is thrown.
+
+$size must be more than or equal to 0. Otherwise an exception is thrown.
+
+$nmemb must be more than or equal to 0. Otherwise an exception is thrown.
+
+$stream must be defined. Otherwise an exception is thrown.
+
+$nmemb * $size must be less than or equal to the length of $ptr - $ptr_offset. Otherwise an exception is thrown.
 
 =head2 feof
 
 C<static method feof : int ($stream : L<Sys::IO::FileStream|SPVM::Sys::IO::FileStream>);>
 
-The function feof() tests the end-of-file indicator for the stream pointed to by stream, returning nonzero if it is set. The end-of-file indicator can only be cleared by the function clearerr().
+Calls the L<feof|https://linux.die.net/man/3/feof> function and returns its return value.
 
-See the L<feof|https://linux.die.net/man/3/feof> function in Linux.
+Exceptions:
 
-The file stream is a L<Sys::IO::FileStream|SPVM::Sys::IO::FileStream> object.
+$stream must be defined. Otherwise an exception is thrown.
 
 =head2 ferror
 
 C<static method ferror : int ($stream : L<Sys::IO::FileStream|SPVM::Sys::IO::FileStream>);>
 
-The function ferror() tests the error indicator for the stream pointed to by stream, returning nonzero if it is set. The error indicator can only be reset by the clearerr() function.
+Calls the L<ferror|https://linux.die.net/man/3/ferror> function and returns its return value.
 
-See the L<ferror|https://linux.die.net/man/3/ferror> function in Linux.
+Exceptions:
 
-The file stream is a L<Sys::IO::FileStream|SPVM::Sys::IO::FileStream> object.
+$stream must be defined. Otherwise an exception is thrown.
 
 =head2 clearerr
 
 C<static method clearerr : void ($stream : L<Sys::IO::FileStream|SPVM::Sys::IO::FileStream>);>
 
-The function clearerr() clears the end-of-file and error indicators for the stream pointed to by stream.
+Calls the L<clearerr|https://linux.die.net/man/3/clearerr> function.
 
-See the L<clearerr|https://linux.die.net/man/3/clearerr> function in Linux.
+Exceptions:
 
-The file stream is a L<Sys::IO::FileStream|SPVM::Sys::IO::FileStream> object.
+$stream must be defined. Otherwise an exception is thrown.
 
 =head2 getc
 
 C<static method getc : int ($stream : L<Sys::IO::FileStream|SPVM::Sys::IO::FileStream>);>
 
-getc() is equivalent to fgetc() except that it may be implemented as a macro which evaluates stream more than once.
+Calls the L<getc|https://linux.die.net/man/3/getc> function and returns its return value.
 
-See the L<getc|https://linux.die.net/man/3/getc> function in Linux.
+Exceptions:
 
-The file stream is a L<Sys::IO::FileStream|SPVM::Sys::IO::FileStream> object.
+$stream must be defined. Otherwise an exception is thrown.
+
+=head2 ungetc
+
+C<static method ungetc : int ($c : int, $stream : L<Sys::IO::FileStream|SPVM::Sys::IO::FileStream>);>
+
+Calls the L<ungetc|https://linux.die.net/man/3/ungetc> function and returns its return value.
+
+Exceptions:
+
+$stream must be defined. Otherwise an exception is thrown.
+
+If the ungetc function failed, an exception is thrown with C<eval_error_id> set to the basic type ID of the L<Error::System|SPVM::Error::System> class.
 
 =head2 fgets
 
 C<static method fgets : mutable string ($s : mutable string, $size : int, $stream : L<Sys::IO::FileStream|SPVM::Sys::IO::FileStream>, $s_offset : int = 0);>
 
-fgets() reads in at most one less than size characters from stream and stores them into the buf pointed to by s + s_offset. Reading stops after an EOF or a newline. If a newline is read, it is stored into the buf. A terminating null byte (aq\0aq) is stored after the last character in the buf.
+Calls the L<fgets|https://linux.die.net/man/3/fgets> function and returns its return value.
 
-See the L<fgets|https://linux.die.net/man/3/fgets> function in Linux.
+Exceptions:
+
+$s must be defined. Otherwise an exception is thrown.
+
+$size must be more than or equal to 0. Otherwise an exception is thrown.
+
+$stream must be defined. Otherwise an exception is thrown.
+
+$size must be less than the length of $s - $s_offset. Otherwise an exception is thrown.
 
 =head2 fwrite
 
 C<static method fwrite : int ($ptr : string, $size : int, $nmemb : int, $stream : L<Sys::IO::FileStream|SPVM::Sys::IO::FileStream>, $ptr_offset : int = 0);>
 
-The function fwrite() writes nmemb elements of data, each size bytes long, to the stream pointed to by stream, obtaining them from the location given by ptr + ptr_offset.
+Calls the L<fwrite|https://linux.die.net/man/3/fwrite> function and returns its return value.
 
-See the L<fread|https://linux.die.net/man/3/fwrite> function in Linux.
+Exceptions:
 
-The file stream is a L<Sys::IO::FileStream|SPVM::Sys::IO::FileStream> object.
+$ptr must be defined. Otherwise an exception is thrown.
 
-=head2 fseek
+$size must be more than or equal to 0. Otherwise an exception is thrown.
 
-C<static method fseek : int ($stream : L<Sys::IO::FileStream|SPVM::Sys::IO::FileStream>, $offset : long, $whence : int);>
+$nmemb must be more than or equal to 0. Otherwise an exception is thrown.
 
-The fseek() function sets the file position indicator for the stream pointed to by stream. The new position, measured in bytes, is obtained by adding offset bytes to the position specified by whence. If whence is set to SEEK_SET, SEEK_CUR, or SEEK_END, the offset is relative to the start of the file, the current position indicator, or end-of-file, respectively. A successful call to the fseek() function clears the end-of-file indicator for the stream and undoes any effects of the ungetc(3) function on the same stream.
+$stream must be defined. Otherwise an exception is thrown.
 
-See the L<fseek|https://linux.die.net/man/3/fseek> function in Linux.
-
-The file stream is a L<Sys::IO::FileStream|SPVM::Sys::IO::FileStream> object.
-
-See L<Sys::IO::Constant|SPVM::Sys::IO::Constant> about the constant value for the whence.
-
-=head2 ftell
-
-C<static method ftell : long ($stream : L<Sys::IO::FileStream|SPVM::Sys::IO::FileStream>);>
-
-The ftell() function obtains the current value of the file position indicator for the stream pointed to by stream.
-
-See the L<ftell|https://linux.die.net/man/3/ftell> function in Linux.
-
-The file stream is a L<Sys::IO::FileStream|SPVM::Sys::IO::FileStream> object.
+$nmemb * $size must be less than or equal to the length of $ptr - $ptr_offset. Otherwise an exception is thrown.
 
 =head2 fclose
 
 C<static method fclose : int ($stream : L<Sys::IO::FileStream|SPVM::Sys::IO::FileStream>);>
 
-The fclose() function flushes the stream pointed to by fp (writing any bufed output data using fflush(3)) and closes the underlying file descriptor.
+Calls the L<fclose|https://linux.die.net/man/3/fclose> function and returns its return value.
 
-See the L<fclose|https://linux.die.net/man/3/fclose> function in Linux.
+If successful, the L<closed|SPVM::Sys::IO::FileStream/"closed"> field is set to 1.
 
-The file stream is a L<Sys::IO::FileStream|SPVM::Sys::IO::FileStream> object.
+Exceptions:
+
+$stream must be defined
+
+If the fclose function failed, an exception is thrown with C<eval_error_id> set to the basic type ID of the L<Error::System|SPVM::Error::System> class.
+
+=head2 fseek
+
+C<static method fseek : int ($stream : L<Sys::IO::FileStream|SPVM::Sys::IO::FileStream>, $offset : long, $whence : int);>
+
+Calls the L<fseek|https://linux.die.net/man/3/fseek> function and returns its return value.
+
+See L<Sys::IO::Constant|SPVM::Sys::IO::Constant> about constant values given to $whence.
+
+Exceptions:
+
+$stream must be defined. Otherwise an exception is thrown.
+
+$offset must be greater than or equal to 0. Otherwise an exception is thrown.
+
+If the fseek function failed, an exception is thrown with C<eval_error_id> set to the basic type ID of the L<Error::System|SPVM::Error::System> class.
+
+=head2 ftell
+
+C<static method ftell : long ($stream : L<Sys::IO::FileStream|SPVM::Sys::IO::FileStream>);>
+
+Calls the L<ftell|https://linux.die.net/man/3/ftell> function and returns its return value.
+
+Exceptions:
+
+$stream must be defined. Otherwise an exception is thrown.
+
+If the ftell function failed, an exception is thrown with C<eval_error_id> set to the basic type ID of the L<Error::System|SPVM::Error::System> class.
 
 =head2 fflush
 
 C<static method fflush : int ($stream : L<Sys::IO::FileStream|SPVM::Sys::IO::FileStream>);>
 
-For output streams, fflush() forces a write of all user-space bufed data for the given output or update stream via the stream's underlying write function. For input streams, fflush() discards any bufed data that has been fetched from the underlying file, but has not been consumed by the application. The open status of the stream is unaffected.
+Calls the L<fflush|https://linux.die.net/man/3/fflush> function and returns its return value.
 
-See the L<fflush|https://linux.die.net/man/3/fflush> function in Linux.
+Exceptions:
+
+$stream must be defined. Otherwise an exception is thrown.
+
+If the fflush function failed, an exception is thrown with C<eval_error_id> set to the basic type ID of the L<Error::System|SPVM::Error::System> class.
+
+=head2 freopen
+
+C<static method freopen : L<Sys::IO::FileStream|SPVM::Sys::IO::FileStream> ($path : string, $mode : string, $stream : L<Sys::IO::FileStream|SPVM::Sys::IO::FileStream>);>
+
+Calls the L<freopen|https://linux.die.net/man/3/freopen> function and returns its return value.
+
+Exceptions:
+
+$path must be defined. Otherwise an exception is thrown.
+
+$mode must be defined. Otherwise an exception is thrown.
+
+$stream must be defined. Otherwise an exception is thrown.
+
+If the freopen function failed, an exception is thrown with C<eval_error_id> set to the basic type ID of the L<Error::System|SPVM::Error::System> class.
+
+=head2 setvbuf
+
+C<static method setvbuf : int ($stream : L<Sys::IO::FileStream|SPVM::Sys::IO::FileStream>, $buf : mutable string, $mode : int, $size : int);>
+
+Calls the L<setvbuf|https://linux.die.net/man/3/setvbuf> function and returns its return value.
+
+See L<Sys::IO::Constant|SPVM::Sys::IO::Constant> about constant values given to $mode.
+
+Exceptions:
+
+$stream must be defined. Otherwise an exception is thrown.
+
+If $buf is defined, $size must be greater than or equal to 0. Otherwise an exception is thrown.
+
+If $buf is defined, $size must be less than or equal to the length of $buf. Otherwise an exception is thrown.
+
+If the setvbuf function failed, an exception is thrown with C<eval_error_id> set to the basic type ID of the L<Error::System|SPVM::Error::System> class.
+
+=head2 setbuf
+
+C<static method setbuf : void ($stream : L<Sys::IO::FileStream|SPVM::Sys::IO::FileStream>, $buf : mutable string);>
+
+Calls the L</"setvbuf"> method given the following mode $mode and size $size.
+
+If $buf is defined, $mode is set to C<_IOFBF>, otherwise C<_IONBF>.
+
+$size is C<BUFSIZ>.
+
+=head2 setbuffer
+
+C<static method setbuffer : void ($stream : L<Sys::IO::FileStream|SPVM::Sys::IO::FileStream>, $buf : mutable string, $size : int);>
+
+Calls the L</"setvbuf"> method given the following mode $mode.
+
+If $buf is defined, $mode is set to C<_IOFBF>, otherwise C<_IONBF>.
+
+=head2 setlinebuf
+
+C<static method setlinebuf : void ($stream : L<Sys::IO::FileStream|SPVM::Sys::IO::FileStream>);>
+
+Calls the L</"setvbuf"> method given the following buffer $buf and mode $mode.
+
+$buf is undef.
+
+$mode is C<_IOLBF>.
+
+$size is C<BUFSIZ>.
+
+=head2 fsync
+
+C<static method fsync : int ($fd : int);>
+
+fsync() transfers ("flushes") all modified in-core data of (i.e., modified buffer cache pages for) the file referred to by the file descriptor fd to the disk device (or other permanent storage device) so that all changed information can be retrieved even after the system crashed or was rebooted.
+
+See L<fsync(2) - Linux man page|https://linux.die.net/man/2/fsync> in Linux.
+
+Exceptions:
 
 =head2 flock
 
@@ -210,6 +334,8 @@ See the L<flock|https://linux.die.net/man/2/flock> function in Linux.
 
 See L<Sys::IO::Constant|SPVM::Sys::IO::Constant> about the constant value for the operation.
 
+Exceptions:
+
 =head2 mkdir
 
 C<static method mkdir : int ($path : string, $mode : int);>
@@ -220,6 +346,8 @@ See the L<mkdir|https://linux.die.net/man/2/mkdir> function in Linux.
 
 See L<Sys::IO::Constant|SPVM::Sys::IO::Constant> about the constant value for the mode.
 
+Exceptions:
+
 =head2 umask
 
 C<static method umask : int ($mode : int);>
@@ -228,6 +356,8 @@ umask() sets the calling process's file mode creation mask (umask) to mask & 077
 
 See the L<umask|https://linux.die.net/man/2/umask> function in Linux.
 
+Exceptions:
+
 =head2 rmdir
 
 C<static method rmdir : int ($path : string);>
@@ -236,6 +366,8 @@ rmdir() deletes a directory, which must be empty.
 
 See the L<rmdir|https://linux.die.net/man/2/rmdir> function in Linux.
 
+Exceptions:
+
 =head2 unlink
 
 C<static method unlink : int ($pathname : string);>
@@ -244,6 +376,8 @@ unlink() deletes a name from the file system. If that name was the last link to
 
 See the L<unlink|https://linux.die.net/man/2/unlink> function in Linux.
 
+Exceptions:
+
 =head2 rename
 
 C<static method rename : int ($oldpath : string, $newpath : string);>
@@ -252,6 +386,8 @@ rename() renames a file, moving it between directories if required. Any other ha
 
 See the L<rename|https://linux.die.net/man/2/rename> function in Linux.
 
+Exceptions:
+
 =head2 getcwd
 
 C<static method getcwd : mutable string ($buf : mutable string, $size : int);>
@@ -260,6 +396,8 @@ The getcwd() function copies an absolute pathname of the current working directo
 
 See the L<getcwd|https://linux.die.net/man/2/getcwd> function in Linux.
 
+Exceptions:
+
 =head2 _getdcwd
 
 C<static method _getdcwd : mutable string ($drive : int, $buffer : mutable string, $maxlen : int);>
@@ -268,6 +406,8 @@ Gets the full path of the current working directory on the specified drive.
 
 See the L<_getdcwd|https://docs.microsoft.com/en-us/cpp/c-runtime-library/reference/getdcwd-wgetdcwd?view=msvc-170> function in the case of Windows.
 
+Exceptions:
+
 =head2 realpath
 
 C<static method realpath : mutable string ($path : string, $resolved_path : mutable string);>
@@ -276,6 +416,8 @@ realpath() expands all symbolic links and resolves references to /./, /../ and e
 
 See the L<realpath|https://linux.die.net/man/3/realpath> function in Linux.
 
+Exceptions:
+
 =head2 _fullpath
 
 C<native static method _fullpath : mutable string ($absPath : mutable string, $relPath : string, $maxLength : int);>
@@ -284,6 +426,8 @@ Creates an absolute or full path name for the specified relative path name.
 
 See the L<_fullpath|https://docs.microsoft.com/en-us/cpp/c-runtime-library/reference/fullpath-wfullpath?view=msvc-170> function in the case of Windows.
 
+Exceptions:
+
 =head2 chdir
 
 C<static method chdir : int ($path : string);>
@@ -292,6 +436,8 @@ chdir() changes the current working directory of the calling process to the dire
 
 See the L<chdir|https://linux.die.net/man/2/chdir> function in Linux.
 
+Exceptions:
+
 =head2 chmod
 
 C<static method chmod : int ($path : string, $mode :int);>
@@ -302,6 +448,8 @@ See the L<chmod|https://linux.die.net/man/2/chmod> function in Linux.
 
 See L<Sys::IO::Constant|SPVM::Sys::IO::Constant> about the constant value for the mode.
 
+Exceptions:
+
 =head2 chown
 
 C<static method chown : int ($path : string, $owner : int, $group : int);>
@@ -310,6 +458,8 @@ chown() changes the ownership of the file specified by path, which is dereferenc
 
 See the L<chown|https://linux.die.net/man/2/chown> function in Linux.
 
+Exceptions:
+
 =head2 truncate
 
 C<static method truncate : int ($path : string, $length : long);>
@@ -318,6 +468,8 @@ The truncate() and ftruncate() functions cause the regular file named by path or
 
 See the L<truncate|https://linux.die.net/man/2/truncate> function in Linux.
 
+Exceptions:
+
 =head2 symlink
 
 C<static method symlink : int ($oldpath : string, $newpath : string);>
@@ -326,6 +478,8 @@ symlink() creates a symbolic link named newpath which contains the string oldpat
 
 See the L<symlink|https://linux.die.net/man/2/symlink> function in Linux.
 
+Exceptions:
+
 =head2 readlink
 
 C<static method readlink : int ($path : string, $buf : mutable string, $bufsiz : int);>
@@ -334,12 +488,16 @@ readlink() places the contents of the symbolic link path in the buf buf, which h
 
 See the L<readlink|https://linux.die.net/man/2/readlink> function in Linux.
 
+Exceptions:
+
 =head2 get_readlink_buffer_size
 
 C<native static method get_readlink_buffer_size : int ($path : string);>
 
 Gets the L</"readlink"> needed buffer size.
 
+Exceptions:
+
 =head2 opendir
 
 C<static method opendir : L<Sys::IO::DirStream|SPVM::Sys::IO::DirStream> ($dir : string);>
@@ -350,6 +508,8 @@ See the L<opendir|https://linux.die.net/man/3/opendir> function in Linux.
 
 The return value is a L<Sys::IO::DirStream|SPVM::Sys::IO::DirStream> object.
 
+Exceptions:
+
 =head2 closedir
 
 C<static method closedir : int ($dirp : L<Sys::IO::DirStream|SPVM::Sys::IO::DirStream>);>
@@ -360,6 +520,8 @@ See the L<closedir|https://linux.die.net/man/3/closedir> function in Linux.
 
 The directory stream is a L<Sys::IO::DirStream|SPVM::Sys::IO::DirStream> object.
 
+Exceptions:
+
 =head2 readdir
 
 C<static method readdir : L<Sys::IO::Dirent|SPVM::Sys::IO::Dirent> ($dirp : L<Sys::IO::DirStream|SPVM::Sys::IO::DirStream>); # Non-thead safe>
@@ -372,6 +534,8 @@ The directory stream is a L<Sys::IO::DirStream|SPVM::Sys::IO::DirStream> object.
 
 The return value is a L<Sys::IO::Dirent|SPVM::Sys::IO::Dirent> object.
 
+Exceptions:
+
 =head2 rewinddir
 
 C<static method rewinddir : void ($dirp : L<Sys::IO::DirStream|SPVM::Sys::IO::DirStream>);>
@@ -382,6 +546,8 @@ See the L<rewinddir|https://linux.die.net/man/3/rewinddir> function in Linux.
 
 The directory stream is a L<Sys::IO::DirStream|SPVM::Sys::IO::DirStream> object.
 
+Exceptions:
+
 =head2 telldir
 
 C<static method telldir : long ($dirp : L<Sys::IO::DirStream|SPVM::Sys::IO::DirStream>);>
@@ -392,6 +558,8 @@ See the L<telldir|https://linux.die.net/man/3/telldir> function in Linux.
 
 The directory stream is a L<Sys::IO::DirStream|SPVM::Sys::IO::DirStream> object.
 
+Exceptions:
+
 =head2 seekdir
 
 C<static method seekdir : void ($dirp : L<Sys::IO::DirStream|SPVM::Sys::IO::DirStream>, $offset : long);>
@@ -401,15 +569,7 @@ See the L<seekdir|https://linux.die.net/man/3/seekdir> function in Linux.
 
 The directory stream is a L<Sys::IO::DirStream|SPVM::Sys::IO::DirStream> object.
 
-=head2 utime
-
-C<static method utime : int ($filename : string, $times : L<Sys::IO::Utimbuf|SPVM::Sys::IO::Utimbuf>);>
-
-The utime() system call changes the access and modification times of the inode specified by filename to the actime and modtime fields of times respectively.
-
-See the L<utime|https://linux.die.net/man/2/utime> function in Linux.
-
-The buf is a L<Sys::IO::Utimbuf|SPVM::Sys::IO::Utimbuf> object.
+Exceptions:
 
 =head2 access
 
@@ -421,6 +581,8 @@ See the L<access|https://linux.die.net/man/2/access> function in Linux.
 
 See L<Sys::IO::Constant|SPVM::Sys::IO::Constant> about the constant value for the mode.
 
+Exceptions:
+
 =head2 eaccess
 
 C<static method eaccess : int ($pathname : string, $mode : int);>
@@ -431,6 +593,8 @@ See the L<eaccess|https://linux.die.net/man/3/eaccess> function in Linux.
 
 See L<Sys::IO::Constant|SPVM::Sys::IO::Constant> about the constant value for the $mode.
 
+Exceptions:
+
 =head2 faccessat
 
   static method faccessat : int ($dirfd : int, $pathname : string, $mode : int, $flags : int);
@@ -441,41 +605,7 @@ See the L<faccessat|https://linux.die.net/man/2/faccessat> function in Linux.
 
 See L<Sys::IO::Constant|SPVM::Sys::IO::Constant> about the constant value for the $mode and $flag.
 
-=head2 stat_raw
-
-C<static method stat_raw : int ($path : string, $stat : L<Sys::IO::Stat|SPVM::Sys::IO::Stat>);>
-
-The same as L</"stat">, but even if the return value is C<-1>, an exception will not be thrown.
-
-=head2 stat
-
-C<static method stat : int ($path : string, $stat : L<Sys::IO::Stat|SPVM::Sys::IO::Stat>);>
-
-These functions return information about a file. No permissions are required on the file itself, but-in the case of stat() and lstat() - execute (search) permission is required on all of the directories in path that lead to the file.
-
-stat() stats the file pointed to by path and fills in buf.
-
-See the L<stat|https://linux.die.net/man/2/stat> function in Linux.
-
-The stat is L<Sys::IO::Stat|SPVM::Sys::IO::Stat> object.
-
-=head2 lstat_raw
-
-C<static method lstat_raw : int ($path : string, $stat : L<Sys::IO::Stat|SPVM::Sys::IO::Stat>);>
-
-The same as L</"lstat">, but even if the return value is C<-1>, an exception will not be thrown.
-
-=head2 lstat
-
-C<static method lstat : int ($path : string, $stat : L<Sys::IO::Stat|SPVM::Sys::IO::Stat>);>
-
-These functions return information about a file. No permissions are required on the file itself, but-in the case of stat() and lstat() - execute (search) permission is required on all of the directories in path that lead to the file.
-
-lstat() is identical to stat(), except that if path is a symbolic link, then the link itself is stat-ed, not the file that it refers to.
-
-See the L<lstat|https://linux.die.net/man/2/lstat> function in Linux.
-
-The stat is L<Sys::IO::Stat|SPVM::Sys::IO::Stat> object.
+Exceptions:
 
 =head2 fcntl
 
@@ -487,6 +617,8 @@ See the L<lstat|https://linux.die.net/man/2/fcntl> function in Linux.
 
 The command argument can receive a L<Sys::IO::Flock|SPVM::Sys::IO::Flock> object.
 
+Exceptions:
+
 =head2 ftruncate
 
 C<static method ftruncate : int ($fd : int, $length : long);>
@@ -495,138 +627,61 @@ The ftruncate() functions cause the regular file named by referenced by fd to be
 
 See L<ftruncate(2) - Linux man page|https://linux.die.net/man/2/ftruncate> in Linux.
 
-=head2 ungetc
+Exceptions:
 
-C<static method ungetc : int ($c : int, $stream : L<Sys::IO::FileStream|SPVM::Sys::IO::FileStream>);>
+=head2 open
 
-ungetc() pushes c back to stream, cast to unsigned char, where it is available for subsequent read operations. Pushed-back characters will be returned in reverse order; only one pushback is guaranteed.
+C<static method open : int ($path : string, $flags : int, $mode : int = 0);>
 
-See L<ungetc(3) - Linux man page|https://linux.die.net/man/3/ungetc> in Linux.
+Given a pathname for a file, open() returns a file descriptor, a small, nonnegative integer for use in subsequent system calls (read(2), write(2), lseek(2), fcntl(2), etc.). The file descriptor returned by a successful call will be the lowest-numbered file descriptor not currently open for the process.
 
-=head2 fsync
+See the L<open|https://linux.die.net/man/2/open> function in Linux.
 
-C<static method fsync : int ($fd : int);>
+See L<Sys::IO::Constant|SPVM::Sys::IO::Constant> about the constant value for the flags and the mode.
 
-fsync() transfers ("flushes") all modified in-core data of (i.e., modified buffer cache pages for) the file referred to by the file descriptor fd to the disk device (or other permanent storage device) so that all changed information can be retrieved even after the system crashed or was rebooted.
+Exceptions:
 
-See L<fsync(2) - Linux man page|https://linux.die.net/man/2/fsync> in Linux.
+=head2 read
 
-=head2 fstat_raw
+C<static method read : int ($fd : int, $buf : mutable string, $count : int, $buf_offset : int = 0);>
 
-C<static method fstat_raw : int ($fd : int, $stat : L<Sys::IO::Stat|SPVM::Sys::IO::Stat>);>
+read() attempts to read up to count bytes from file descriptor fd into the buf starting at buf + buf_offset.
 
-The same as L</"fstat">, but even if the return value is C<-1>, an exception will not be thrown.
+See the L<read|https://linux.die.net/man/2/read> function in Linux.
 
-=head2 fstat
+Exceptions:
 
-C<static method fstat : int ($fd : int, $stat : L<Sys::IO::Stat|SPVM::Sys::IO::Stat>);>
+=head2 write
 
-fstat() is identical to stat(), except that the file to be stat-ed is specified by the file descriptor fd.
+C<static method write : int ($fd : int, $buf : string, $count : int, $buf_offset : int = 0);>
 
-See L<fstat(2) - Linux man page|https://linux.die.net/man/2/fsync> in Linux.
+write() writes up to count bytes from the buf pointed buf + buf_offset to the file referred to by the file descriptor fd.
 
-The C<$stat> is a L<Sys::IO::Stat|SPVM::Sys::IO::Stat> object.
+See the L<write|https://linux.die.net/man/2/write> function in Linux.
 
-=head2 freopen
+Exceptions:
 
-C<static method freopen : L<Sys::IO::FileStream|SPVM::Sys::IO::FileStream> ($path : string, $mode : string, $stream : L<Sys::IO::FileStream|SPVM::Sys::IO::FileStream>);>
+=head2 lseek
 
-The freopen() function opens the file whose name is the string pointed to by path and associates the stream pointed to by stream with it.
+C<static method lseek : long ($fd : int, $offset : long, $whence : int);>
 
-See L<freopen(3) - Linux man page|https://linux.die.net/man/3/freopen> in Linux.
+The lseek() function repositions the offset of the open file associated with the file descriptor fd to the argument offset according to the directive whence as follows:
 
-=head2 setvbuf
+See the L<lseek|https://linux.die.net/man/2/lseek> function in Linux.
 
-C<static method setvbuf : int ($stream : L<Sys::IO::FileStream|SPVM::Sys::IO::FileStream>, $buf : mutable string, $mode : int, $size : int);>
+See L<Sys::IO::Constant|SPVM::Sys::IO::Constant> about the constant value for the whence.
 
-The setvbuf() function may be used on any open stream to change its buffer.
+Exceptions:
 
-See L<setvbuf(3) - Linux man page|https://linux.die.net/man/3/setvbuf> in Linux.
+=head2 close
 
-See L<Sys::IO::Constant|SPVM::Sys::IO::Constant> about the constant value for the C<$mode>.
+C<static method close : int ($fd : int);>
 
-=head2 setbuf
+close() closes a file descriptor, so that it no longer refers to any file and may be reused. Any record locks (see fcntl(2)) held on the file it was associated with, and owned by the process, are removed (regardless of the file descriptor that was used to obtain the lock).
 
-C<static method setbuf : void ($stream : L<Sys::IO::FileStream|SPVM::Sys::IO::FileStream>, $buf : mutable string);>
+See the L<close|https://linux.die.net/man/2/close> function in Linux.
 
-The same as the following code using L</"setvbuf">.
-
-    my $mode : int;
-    if ($buf) {
-      $mode = IO->_IOFBF;
-    }
-    else {
-      $mode = IO->_IONBF;
-    }
-    
-    &setvbuf($stream, $buf, $mode, IO->BUFSIZ);
-
-=head2 setbuffer
-
-C<static method setbuffer : void ($stream : L<Sys::IO::FileStream|SPVM::Sys::IO::FileStream>, $buf : mutable string, $size : int);>
-
-The same as the following code using L</"setvbuf">.
-
-  my $mode : int;
-  if ($buf) {
-    $mode = IO->_IOFBF;
-  }
-  else {
-    $mode = IO->_IONBF;
-  }
-  
-  &setvbuf($stream, $buf, $mode, $size);
-
-=head2 setlinebuf
-
-C<static method setlinebuf : void ($stream : L<Sys::IO::FileStream|SPVM::Sys::IO::FileStream>);>
-
-The same as the following code using L</"setvbuf">.
-
-  my $mode = IO->_IOLBF;
-  &setvbuf($stream, undef, $mode, IO->BUFSIZ);
-
-=head2 stdin
-
-C<static method stdin : L<Sys::IO::FileStream|SPVM::Sys::IO::FileStream> ();>
-
-Returns a L<Sys::IO::FileStream|SPVM::Sys::IO::FileStream> object that has the pointer to the stream that C<stdin> in the C language returns.
-
-See L<stdin(3) - Linux man page|https://linux.die.net/man/3/stdin> in Linux.
-
-=head2 stdout
-
-C<static method stdout : L<Sys::IO::FileStream|SPVM::Sys::IO::FileStream> ();>
-
-Returns a L<Sys::IO::FileStream|SPVM::Sys::IO::FileStream> object that has the pointer to the stream that C<stdout> in the C language returns.
-
-See L<stdout(3) - Linux man page|https://linux.die.net/man/3/stdout> in Linux.
-
-=head2 stderr
-
-C<static method stderr : L<Sys::IO::FileStream|SPVM::Sys::IO::FileStream> ();>
-
-Returns a L<Sys::IO::FileStream|SPVM::Sys::IO::FileStream> object that has the pointer to the stream that C<stderr> in the C language returns.
-
-See L<stderr(3) - Linux man page|https://linux.die.net/man/3/stderr> in Linux.
-
-=head2 spvm_stdin
-
-C<static method spvm_stdin : L<Sys::IO::FileStream|SPVM::Sys::IO::FileStream> ();>
-
-Returns the stdin opened by the SPVM language.
-
-=head2 spvm_stdout
-
-C<static method spvm_stdout : L<Sys::IO::FileStream|SPVM::Sys::IO::FileStream> ();>
-
-Returns the stdin opened by the SPVM language.
-
-=head2 spvm_stderr
-
-C<static method spvm_stderr : L<Sys::IO::FileStream|SPVM::Sys::IO::FileStream> ();>
-
-Returns the stdin opened by the SPVM language.
+Exceptions:
 
 =head2 popen
 
@@ -642,6 +697,8 @@ $type must be defined. Otherwise an exception is thrown.
 
 If the popen function failed, an exception is thrown with C<eval_error_id> set to the basic type ID of the L<Error::System|SPVM::Error::System> class.
 
+Exceptions:
+
 =head2 _popen
 
 C<static method _popen : L<Sys::IO::FileStream|SPVM::Sys::IO::FileStream> ($command : string, $type : string);>
@@ -656,6 +713,8 @@ $type must be defined. Otherwise an exception is thrown.
 
 If the _popen function failed, an exception is thrown with C<eval_error_id> set to the basic type ID of the L<Error::System|SPVM::Error::System> class.
 
+Exceptions:
+
 =head2 pclose
 
 C<static method pclose : int ($stream : L<Sys::IO::FileStream|SPVM::Sys::IO::FileStream>);>
@@ -668,6 +727,8 @@ $stream must be defined. Otherwise an exception is thrown.
 
 If the pclose function failed, an exception is thrown with C<eval_error_id> set to the basic type ID of the L<Error::System|SPVM::Error::System> class.
 
+Exceptions:
+
 =head2 _pclose
 
 C<static method _pclose : int ($stream : L<Sys::IO::FileStream|SPVM::Sys::IO::FileStream>);>
