@@ -1770,3 +1770,27 @@ int32_t SPVM__Sys__IO__Constant___IOFBF(SPVM_ENV* env, SPVM_VALUE* stack) {
 
 }
 
+int32_t SPVM__Sys__IO__Constant__O_BINARY(SPVM_ENV* env, SPVM_VALUE* stack) {
+
+#ifdef O_BINARY
+  stack[0].ival = O_BINARY;
+  return 0;
+#else
+  env->die(env, stack, "O_BINARY is not defined in this system.", __func__, FILE_NAME, __LINE__);
+  return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
+#endif
+
+}
+
+int32_t SPVM__Sys__IO__Constant__O_TEXT(SPVM_ENV* env, SPVM_VALUE* stack) {
+
+#ifdef O_TEXT
+  stack[0].ival = O_TEXT;
+  return 0;
+#else
+  env->die(env, stack, "O_TEXT is not defined in this system.", __func__, FILE_NAME, __LINE__);
+  return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
+#endif
+
+}
+
