@@ -6,16 +6,18 @@ package SPVM::Sys::IO::Flock;
 
 SPVM::Sys::IO::Flock - struct flock in the C language
 
+=head1 Description
+
+The Sys::IO::Flock class of L<SPVM> is the class for C<struct flock> in the C language.
+
 =head1 Usage
 
   use Sys::IO::Flock;
   my $flock = Sys::IO::Flock->new;
 
-=head1 Description
+=head1 Details
 
-C<Sys::IO::Flock> is the class for C<struct flock> in the C language.
-
-This is a L<pointer class|SPVM::Document::Language/"Pointer Class">.
+This is a pointer class. The pointer of the instance is set to a C<struct flock> object.
 
 =head1 Class Methods
 
@@ -37,61 +39,61 @@ The destructor.
 
 C<native method l_type : int ();>
 
-Get C<l_type>.
+Gets C<l_type>.
 
 =head2 set_l_type
 
 C<native method set_l_type : void ($type : int);>
 
-Set C<l_type>.
+Sets C<l_type>.
 
 =head2 l_whence
 
 C<native method l_whence : int ();>
 
-Get C<l_whence>.
+Gets C<l_whence>.
 
 =head2 set_l_whence
 
 C<native method set_l_whence : void ($whence : int);>
 
-Set C<l_whence>.
+Sets C<l_whence>.
 
 =head2 l_start
 
 C<native method l_start : long ();>
 
-Get C<l_start>.
+Gets C<l_start>.
 
 =head2 set_l_start
 
 C<native method set_l_start : void ($start : long);>
 
-Set C<l_start>.
+Sets C<l_start>.
 
 =head2 l_len
 
 C<native method l_len : long ();>
 
-Get C<l_len>.
+Gets C<l_len>.
 
 =head2 set_l_len
 
 C<native method set_l_len : void ($len : long);>
 
-Set C<l_len>.
+Sets C<l_len>.
 
 =head2 l_pid
 
 C<native method l_pid : int ();>
 
-Get C<l_pid>.
+Gets C<l_pid>.
 
 =head2 set_l_pid
 
 C<native method set_l_pid : void ($pid : int);>
 
-Set C<l_pid>.
+Sets C<l_pid>.
 
 =head1 Copyright & License
 
