@@ -4,7 +4,11 @@ package SPVM::Sys::Time::Timezone;
 
 =head1 Name
 
-SPVM::Sys::Time::Timezone - struct timezone in C language
+SPVM::Sys::Time::Timezone - struct timezone in the C language
+
+=head1 Description
+
+The Sys::Time::Timezone class of L<SPVM> represents L<struct timezone|https://linux.die.net/man/2/gettimeofday> in the C language.
 
 =head1 Usage
   
@@ -18,56 +22,40 @@ SPVM::Sys::Time::Timezone - struct timezone in C language
   my $tz_dsttime = $tz->tz_dsttime;
   $tz->set_tz_dsttime(34);
 
-=head1 Description
-
-C<Sys::Time::Timezone> represents C<struct timezone> in C<C language>.
-
-See L<gettimeofday(2) - Linux man page|https://linux.die.net/man/2/gettimeofday> about C<struct timezone> in Linux.
-
 =head1 Class Methods
 
 =head2 new
 
-C<static method new : L<Sys::Time::Timezone|SPVM::Sys::Time::Timezone> ()>
+C<static method new : L<Sys::Time::Timezone|SPVM::Sys::Time::Timezone> ();>
 
-Creates a new C<Sys::Time::Timezone> object.
-
-  my $tz = Sys::Time::Timezone->new;
+Creates a new L<Sys::Time::Timezone|SPVM::Sys::Time::Timezone> object.
 
 =head1 Instance Methods
 
 =head2 tz_minuteswest
 
-C<method tz_minuteswest : int ()>
+C<method tz_minuteswest : int ();>
 
 Gets C<tz_minuteswest>.
 
-  my $tz_minuteswest = $tz->tz_minuteswest;
-
 =head2 set_tz_minuteswest
 
-C<method set_tz_minuteswest : void ($tz_minuteswest : int)>
+C<method set_tz_minuteswest : void ($tz_minuteswest : int);>
 
 Sets C<tz_minuteswest>.
 
-  $tz->set_tz_minuteswest(12);
-
 =head2 tz_dsttime
   
-C<method tz_dsttime : int ()>
+C<method tz_dsttime : int ();>
 
 Gets C<tz_dsttime>.
 
-  my $tz_dsttime = $tz->tz_dsttime;
-
 =head2 set_tz_dsttime
 
-C<method set_tz_dsttime : void ($tz_dsttime : int)>
+C<method set_tz_dsttime : void ($tz_dsttime : int);>
 
 Sets C<tz_dsttime>.
 
-  $tz->set_tz_dsttime(34);
-
 =head1 Copyright & License
 
 Copyright (c) 2023 Yuki Kimoto
